#
# spec file for package ghc-hslua
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hslua
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.1
Release:        lp150.1.8
Summary:        A Lua language interpreter embedding in Haskell
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  lua51-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-contrib-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-text-devel
%endif

%description
The Scripting.Lua module is a wrapper of Lua language interpreter as described
in [lua.org](http://www.lua.org/).

This package contains full Lua interpreter version 5.1.5. If you want to link
it with system-wide Lua installation, use 'system-lua' flag.

[Example programs](https://github.com/osa1/hslua/tree/master/examples).

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       lua51-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%define cabal_configure_options -fsystem-lua --extra-include-dirs=$(pkg-config --variable=includedir lua)
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc COPYRIGHT

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md examples

%changelog
* Thu Aug 17 2017 dimstar@opensuse.org
- Fix build with the new lua package layout by specifying
  - -extra-include-dirs based on lua.pc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.1 revision 0 with cabal2obs.
* Sun Sep 13 2015 mimi.vx@gmail.com
- update to 0.4.1
  * Bugfix: tolist wasn't popping elements of the list from stack.
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 0.4.0
  * pushstring and tostring now uses ByteString instead of [Char].
  * StackValue [Char] instance is removed, StackValue ByteString is added.
  * StackValue a => StackValue [a] instance is added. It pushes a Lua array to the stack. pushlist,
  islist and tolist functions are added.
  * Type errors in Haskell functions now propagated differently. See the Scripting.Lua
  documentation for detailed explanation. This should fix segfaults reported several times.
  * lua_error function is removed, it's never safe to call in Haskell.
  * Pkgconf-based setup removed. Cabal is now using extra-libraries to link with Lua.
  * luajit flag is added to link hslua with LuaJIT.
* Tue Apr 21 2015 mimi.vx@gmail.com
- update to 0.3.13
  * `pushrawhsfunction` and `registerrawhsfunction` functions are added.
  * `luaL_ref` and `luaL_unref` functions are added.
* Tue Apr  7 2015 peter.trommler@ohm-hochschule.de
- update to 0.3.9
- drop include-lua_neutralize_longjmp.patch
  * fixed upstream
* Wed Mar 26 2014 peter.trommler@ohm-hochschule.de
- fix license tag
  * license file contradicts license tag in cabal file
* Fri Nov  1 2013 sbahling@suse.com
- Proper lua-devel BuildRequires for SLE_11
* Mon Oct 21 2013 sbahling@suse.com
- include-lua_neutralize_longjmp.patch:
  Include custom lua_neutralize_longjmp function when compiling
  using system lua libraries.
* Mon Oct 21 2013 sbahling@suse.com
- Use lua51. Pandoc needs 5.1 API.
* Fri Oct 18 2013 peter.trommler@ohm-hochschule.de
- use system provided lua library
* Sun Oct  6 2013 sbahling@suse.com
- Intial package - version 0.3.7
